@@ -1,4 +1,4 @@
 library(drfit)
 data(antifoul)
 rantifoul <- drfit(antifoul)
-rantifoul
+print(rantifoul,digits=5)
